Task: MultiNLI
===============
Description: A dataset designed for use in the development and evaluation of machine learning models for sentence understanding. Each example contains a premise and hypothesis. Model has to predict whether premise and hypothesis entail, contradict or are neutral to each other. From Williams et al. '17. 

Link: https://arxiv.org/abs/1704.05426

Tags: #MultiNLI, #All, #Entailment, #decanlp

